@@ -1,15 +1,15 @@
 """
 Utilities and common tasks for wrapping the GMT modules.
 """
-import sys
 import shutil
 import subprocess
+import sys
 import webbrowser
+from collections.abc import Iterable
 from contextlib import contextmanager
 
 import xarray as xr
-
-from ..exceptions import GMTInvalidInput
+from pygmt.exceptions import GMTInvalidInput
 
 
 def data_kind(data, x=None, y=None, z=None):
@@ -19,6 +19,7 @@ def data_kind(data, x=None, y=None, z=None):
     Possible types:
 
     * a file name provided as 'data'
+    * an xarray.DataArray provided as 'data'
     * a matrix provided as 'data'
     * 1D arrays x and y (and z, optionally)
 
@@ -27,30 +28,32 @@ def data_kind(data, x=None, y=None, z=None):
 
     Parameters
     ----------
-    data : str, 2d array, or None
-       Data file name or numpy array.
-    x, y : 1d arrays or None
+    data : str, xarray.DataArray, 2d array, or None
+       Data file name, xarray.DataArray or numpy array.
+    x/y : 1d arrays or None
         x and y columns as numpy arrays.
-    z    : 1d array or None
+    z : 1d array or None
         z column as numpy array. To be used optionally when x and y
         are given.
 
     Returns
     -------
     kind : str
-        One of: ``'file'``, ``'matrix'``, ``'vectors'``.
+        One of: ``'file'``, ``'grid'``, ``'matrix'``, ``'vectors'``.
 
     Examples
     --------
 
     >>> import numpy as np
+    >>> import xarray as xr
     >>> data_kind(data=None, x=np.array([1, 2, 3]), y=np.array([4, 5, 6]))
     'vectors'
     >>> data_kind(data=np.arange(10).reshape((5, 2)), x=None, y=None)
     'matrix'
-    >>> data_kind(data='my-data-file.txt', x=None, y=None)
+    >>> data_kind(data="my-data-file.txt", x=None, y=None)
     'file'
-
+    >>> data_kind(data=xr.DataArray(np.random.rand(4, 3)))
+    'grid'
     """
     if data is None and x is None and y is None:
         raise GMTInvalidInput("No input data provided.")
@@ -89,10 +92,10 @@ def dummy_context(arg):
     Examples
     --------
 
-    >>> with dummy_context('some argument') as temp:
+    >>> with dummy_context("some argument") as temp:
     ...     print(temp)
+    ...
     some argument
-
     """
     yield arg
 
@@ -122,19 +125,31 @@ def build_arg_string(kwargs):
     Examples
     --------
 
-    >>> print(build_arg_string(dict(R='1/2/3/4', J="X4i", P='', E=200)))
+    >>> print(
+    ...     build_arg_string(
+    ...         dict(R="1/2/3/4", J="X4i", P="", E=200, X=None, Y=None)
+    ...     )
+    ... )
     -E200 -JX4i -P -R1/2/3/4
-    >>> print(build_arg_string(dict(R='1/2/3/4', J="X4i",
-    ...                             B=['xaf', 'yaf', 'WSen'],
-    ...                             I=('1/1p,blue', '2/0.25p,blue'))))
+    >>> print(
+    ...     build_arg_string(
+    ...         dict(
+    ...             R="1/2/3/4",
+    ...             J="X4i",
+    ...             B=["xaf", "yaf", "WSen"],
+    ...             I=("1/1p,blue", "2/0.25p,blue"),
+    ...         )
+    ...     )
+    ... )
     -Bxaf -Byaf -BWSen -I1/1p,blue -I2/0.25p,blue -JX4i -R1/2/3/4
-
     """
     sorted_args = []
     for key in sorted(kwargs):
         if is_nonstr_iter(kwargs[key]):
             for value in kwargs[key]:
                 sorted_args.append("-{}{}".format(key, value))
+        elif kwargs[key] is None:  # arguments like -XNone are invalid
+            continue
         else:
             sorted_args.append("-{}{}".format(key, kwargs[key]))
 
@@ -159,7 +174,7 @@ def is_nonstr_iter(value):
     Examples
     --------
 
-    >>> is_nonstr_iter('abc')
+    >>> is_nonstr_iter("abc")
     False
     >>> is_nonstr_iter(10)
     False
@@ -167,14 +182,13 @@ def is_nonstr_iter(value):
     True
     >>> is_nonstr_iter((1, 2, 3))
     True
-
+    >>> import numpy as np
+    >>> is_nonstr_iter(np.array([1.0, 2.0, 3.0]))
+    True
+    >>> is_nonstr_iter(np.array(["abc", "def", "ghi"]))
+    True
     """
-    try:
-        [item for item in value]  # pylint: disable=pointless-statement
-        is_iterable = True
-    except TypeError:
-        is_iterable = False
-    return bool(not isinstance(value, str) and is_iterable)
+    return isinstance(value, Iterable) and not isinstance(value, str)
 
 
 def launch_external_viewer(fname):
@@ -188,7 +202,6 @@ def launch_external_viewer(fname):
     ----------
     fname : str
         The file name of the file (preferably a full path).
-
     """
     # Redirect stdout and stderr to devnull so that the terminal isn't filled
     # with noise
@@ -196,9 +209,36 @@ def launch_external_viewer(fname):
 
     # Open the file with the default viewer.
     # Fall back to the browser if can't recognize the operating system.
-    if sys.platform.startswith("linux") and shutil.which("xdg-open"):
-        subprocess.run(["xdg-open", fname], **run_args)
-    elif sys.platform == "darwin":  # Darwin is macOS
-        subprocess.run(["open", fname], **run_args)
+    os_name = sys.platform
+    if os_name.startswith(("linux", "freebsd")) and shutil.which("xdg-open"):
+        subprocess.run(["xdg-open", fname], check=False, **run_args)
+    elif os_name == "darwin":  # Darwin is macOS
+        subprocess.run(["open", fname], check=False, **run_args)
     else:
         webbrowser.open_new_tab("file://{}".format(fname))
+
+
+def args_in_kwargs(args, kwargs):
+    """
+    Take a list and a dictionary, and determine if any entries in the list are
+    keys in the dictionary.
+
+    This function is used to determine if at least one of the required
+    arguments is passed to raise a GMTInvalidInput Error.
+
+    Parameters
+    ----------
+    args : list
+        List of required arguments, using the GMT short-form aliases.
+
+    kwargs : dict
+        The dictionary of kwargs is the format returned by the _preprocess
+        function of the BasePlotting class. The keys are the GMT
+        short-form aliases of the parameters.
+
+    Returns
+    --------
+    bool
+        If one of the required arguments is in ``kwargs``.
+    """
+    return any(arg in kwargs for arg in args)
