@@ -1,10 +1,9 @@
 """
-Tests colorbar
+Tests colorbar.
 """
 import pytest
-
-from .. import Figure
-from ..helpers.testing import check_figures_equal
+from pygmt import Figure
+from pygmt.helpers.testing import check_figures_equal
 
 
 @pytest.mark.mpl_image_compare
@@ -20,7 +19,8 @@ def test_colorbar_using_paper_coordinates():
 @pytest.mark.mpl_image_compare
 def test_colorbar_using_paper_coordinates_horizontal():
     """
-    Create colorbar positioned at 0cm,0cm with length 2cm oriented horizontally
+    Create colorbar positioned at 0cm,0cm with length 2cm oriented
+    horizontally.
     """
     fig = Figure()
     fig.colorbar(cmap="rainbow", position="x0c/0c+w2c+h")
@@ -154,3 +154,63 @@ def test_colorbar_scaled_z_values():
     fig = Figure()
     fig.colorbar(cmap="rainbow", scale=0.1, position="x0c/0c+w2c/0.5c")
     return fig
+
+
+@check_figures_equal()
+def test_colorbar_shading_boolean():
+    """
+    Create colorbar and set shading with a Boolean value.
+    """
+    fig_ref, fig_test = Figure(), Figure()
+    # Use single-character arguments for the reference image
+    fig_ref.basemap(R="0/10/0/10", J="X15c", B="a")
+    fig_ref.colorbar(C="geo", I="")
+
+    fig_test.basemap(region=[0, 10, 0, 10], projection="X15c", frame="a")
+    fig_test.colorbar(cmap="geo", shading=True)
+    return fig_ref, fig_test
+
+
+@check_figures_equal()
+def test_colorbar_shading_float():
+    """
+    Create colorbar and set shading with a single float variable.
+    """
+    fig_ref, fig_test = Figure(), Figure()
+    # Use single-character arguments for the reference image
+    fig_ref.basemap(R="0/10/0/10", J="X15c", B="a")
+    fig_ref.colorbar(C="geo", I=0.5)
+
+    fig_test.basemap(region=[0, 10, 0, 10], projection="X15c", frame="a")
+    fig_test.colorbar(cmap="geo", shading=0.5)
+    return fig_ref, fig_test
+
+
+@check_figures_equal()
+def test_colorbar_shading_string():
+    """
+    Create colorbar and set shading by passing the low/high values as a string.
+    """
+    fig_ref, fig_test = Figure(), Figure()
+    # Use single-character arguments for the reference image
+    fig_ref.basemap(R="0/10/0/10", J="X15c", B="a")
+    fig_ref.colorbar(C="geo", I="-0.7/0.2")
+
+    fig_test.basemap(region=[0, 10, 0, 10], projection="X15c", frame="a")
+    fig_test.colorbar(cmap="geo", shading="-0.7/0.2")
+    return fig_ref, fig_test
+
+
+@check_figures_equal()
+def test_colorbar_shading_list():
+    """
+    Create colorbar and set shading by passing the high/low values as a list.
+    """
+    fig_ref, fig_test = Figure(), Figure()
+    # Use single-character arguments for the reference image
+    fig_ref.basemap(R="0/10/0/10", J="X15c", B="a")
+    fig_ref.colorbar(C="geo", I="-0.7/0.2")
+
+    fig_test.basemap(region=[0, 10, 0, 10], projection="X15c", frame="a")
+    fig_test.colorbar(cmap="geo", shading=[-0.7, 0.2])
+    return fig_ref, fig_test
