@@ -3,6 +3,7 @@ Test the sphinx-gallery scraper and code required to make it work.
 """
 import os
 from tempfile import TemporaryDirectory
+
 import pytest
 
 try:
@@ -10,15 +11,17 @@ try:
 except ImportError:
     sphinx_gallery = None
 
-from ..figure import Figure, SHOWED_FIGURES
-from ..sphinx_gallery import PyGMTScraper
+from pygmt.figure import SHOWED_FIGURES, Figure
+from pygmt.sphinx_gallery import PyGMTScraper
 
 
 @pytest.mark.skipif(sphinx_gallery is None, reason="requires sphinx-gallery")
 def test_pygmtscraper():
-    "Make sure the scraper finds the figures and removes them from the pool."
+    """
+    Make sure the scraper finds the figures and removes them from the pool.
+    """
 
-    showed = [fig for fig in SHOWED_FIGURES]
+    showed = SHOWED_FIGURES.copy()
     for _ in range(len(SHOWED_FIGURES)):
         SHOWED_FIGURES.pop()
     try:
@@ -28,7 +31,7 @@ def test_pygmtscraper():
         assert len(SHOWED_FIGURES) == 1
         assert SHOWED_FIGURES[0] is fig
         scraper = PyGMTScraper()
-        with TemporaryDirectory() as tmpdir:
+        with TemporaryDirectory(dir=os.getcwd()) as tmpdir:
             conf = {"src_dir": "meh"}
             fname = os.path.join(tmpdir, "meh.png")
             block_vars = {"image_path_iterator": (i for i in [fname])}
